@@ -1,5 +1,5 @@
 from .app import Application
 from .context import Context
 from .endpoints import Endpoint
-from .guards import EndpointGuard, ServiceGuard
+from .guards import EndpointGuard, ScopedGuard
 from .responses import BadRequest, Unauthorized
