@@ -13,8 +13,9 @@ class Application(object):
     """
     TODO
     """
-    def __init__(self, name: str):
+    def __init__(self, name: str, secret: str):
         self.name = name
+        self.secret = secret
 
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
         return self._flask_app(*args, **kwargs)
@@ -34,11 +35,21 @@ class Application(object):
         app = cls(*args, **kwargs)
 
         # Add endpoints
-        for method, path, endpoint in endpoints:
+        for e in endpoints:
+            assert 3 <= len(e) <= 4
+
+            method, path, endpoint = e[:3]
+
+            if len(e) == 4:
+                guards = e[3]
+            else:
+                guards = []
+
             app.add_endpoint(
                 method=method,
                 path=path,
                 endpoint=endpoint,
+                guards=guards,
             )
 
         # Add health check endpoint
@@ -89,6 +100,7 @@ class Application(object):
             view_func=RequestOrchestrator(
                 endpoint=endpoint,
                 data=data_provider,
+                secret=self.secret,
                 guards=guards,
             ),
         )
