@@ -1,26 +1,36 @@
 from energytt_platform.bus import message_registry
 
-from .auth import UserOnboarded
+from .users import UserOnboarded
 from .tech import TechnologyUpdate, TechnologyRemoved
+from .auth import (
+    MeteringPointOwnerUpdate,
+    MeteringPointDelegateGranted,
+    MeteringPointDelegateRevoked,
+)
 from .measurements import (
     MeasurementUpdate,
     MeasurementRemoved,
+    ImportMeasurements,
 )
 from .meteringpoints import (
     MeteringPointUpdate,
     MeteringPointRemoved,
     MeteringPointTechnologyUpdate,
     MeteringPointAddressUpdate,
-    MeteringPointDelegateGranted,
-    MeteringPointDelegateRevoked,
+    ImportMeteringPoints,
 )
 
 
 message_registry.add(
 
-    # Authentication
+    # Users
     UserOnboarded,
 
+    # Authentication
+    MeteringPointOwnerUpdate,
+    MeteringPointDelegateGranted,
+    MeteringPointDelegateRevoked,
+
     # Technology
     TechnologyUpdate,
     TechnologyRemoved,
@@ -28,13 +38,12 @@ message_registry.add(
     # Measurements
     MeasurementUpdate,
     MeasurementRemoved,
+    ImportMeasurements,
 
     # MeteringPoints
     MeteringPointUpdate,
     MeteringPointRemoved,
     MeteringPointTechnologyUpdate,
     MeteringPointAddressUpdate,
-    MeteringPointDelegateGranted,
-    MeteringPointDelegateRevoked,
 
 )
