@@ -15,7 +15,8 @@ class TestMessageSerializer:
         obj = m.MeasurementAdded(
             subject='12345',
             measurement=Measurement(
-                type=MeasurementType.CONSUMPTION,
+                id='1',
+                type=MeasurementType.consumption,
                 gsrn='12345',
                 amount=123,
                 begin=datetime.now(),
